@@ -955,7 +955,7 @@ def _cast(typ, value):
 #
 
 
-class USState(Enum):
+class USState(str, Enum):
     AK='AK'
     AL='AL'
     AR='AR'
