@@ -956,19 +956,19 @@ def _cast(typ, value):
 #
 
 
-class RelationType(Enum):
+class RelationType(str, Enum):
     """The possible values of the rel attribute."""
     DOWN='down' # An item in this container.
     ADD='add' # Add something to this container.
 
 
-class RelationType2(Enum):
+class RelationType2(str, Enum):
     """The possible values of the rel attribute."""
     DOWN='down' # An item in this container.
     ADD='add' # Add something to this container.
 
 
-class RelationType3(Enum):
+class RelationType3(str, Enum):
     """The possible values of the rel attribute."""
     DOWN='down' # An item in this container.
     ADD='add' # Add something to this container.
